<?php
declare(strict_types=1);

namespace Inti\Elementor;

use Inti\Container\Factory\PluginManagerFactory;
use Inti\Wp\Plugin\Service\PluginManager;

/**
 * Class ConfigProvider
 *
 * @package Inti\Elementor
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-elementor
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return [
            'wp' => [
                'plugins' => [
                    Plugin\RegisterAssets::class,
                    Plugin\RegisterCategories::class => [
                        'inti' => [
                            'title' => 'Inti Elementi',
                        ],
                    ],
                    Plugin\RegisterTags::class => [
                        Tag\Post\FeaturedImage::class,
                    ],
                    Plugin\RegisterWidgets::class => [
                        Widget\Countdown::class,
                    ],
                ],
            ],

            'dependencies' => [
                'factories' => [
                    Document\DocumentManager::class => PluginManagerFactory::class,
                    Tag\TagManager::class => PluginManagerFactory::class,
                    Widget\WidgetManager::class => PluginManagerFactory::class,
                ],
            ],

            PluginManager::class => [
                'factories' => [
                    Plugin\RegisterDocuments::class => Plugin\Factory\RegisterDocumentsFactory::class,
                    Plugin\RegisterWidgets::class => Plugin\Factory\RegisterWidgetsFactory::class,
                ],
            ],
        ];
    }
}
